@@ -6,7 +6,7 @@
 
 /* CDBISDN database */
 const int  CDBISDN_DBVERSION = 0x101;
-const char CDBISDN_DATE[]  = "Tue Aug  5 15:17:33 2025";
+const char CDBISDN_DATE[]  = "Sat Feb 21 11:43:59 2026";
 /* vendor database */
 static cdb_isdn_vendor cdb_isdnvendor_info_init[] = {
 	{"Abocom/Magitek","Abocom",0,1},
